@@ -272,7 +272,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup larrv
+*> \ingroup doubleOTHERauxiliary
 *
 *> \par Contributors:
 *  ==================
@@ -350,7 +350,7 @@
 *
 *     Quick return if possible
 *
-      IF( (N.LE.0).OR.(M.LE.0) ) THEN
+      IF( N.LE.0 ) THEN
          RETURN
       END IF
 *
