@@ -212,7 +212,8 @@
       COMPLEX*16         DUM( 1 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DLASCL, DLASET, XERBLA, ZBDSQR, ZCOPY, ZDRSCL,
+      EXTERNAL           DLASCL, DLASET, XERBLA, ZBDSQR, ZCOPY,
+     $                   ZDRSCL,
      $                   ZGEBRD, ZGELQF, ZGEMM, ZGEMV, ZGEQRF, ZLACPY,
      $                   ZLASCL, ZLASET, ZUNGBR, ZUNMBR, ZUNMLQ
 *     ..
@@ -271,9 +272,11 @@
      $                   LDB, DUM(1), -1, INFO )
                LWORK_ZUNMQR = INT( DUM(1) )
                MM = N
-               MAXWRK = MAX( MAXWRK, N + N*ILAENV( 1, 'ZGEQRF', ' ', M,
+               MAXWRK = MAX( MAXWRK, N + N*ILAENV( 1, 'ZGEQRF', ' ',
+     $                       M,
      $                       N, -1, -1 ) )
-               MAXWRK = MAX( MAXWRK, N + NRHS*ILAENV( 1, 'ZUNMQR', 'LC',
+               MAXWRK = MAX( MAXWRK, N + NRHS*ILAENV( 1, 'ZUNMQR',
+     $                       'LC',
      $                       M, NRHS, N, -1 ) )
             END IF
             IF( M.GE.N ) THEN
@@ -281,11 +284,13 @@
 *              Path 1 - overdetermined or exactly determined
 *
 *              Compute space needed for ZGEBRD
-               CALL ZGEBRD( MM, N, A, LDA, S, S, DUM(1), DUM(1), DUM(1),
+               CALL ZGEBRD( MM, N, A, LDA, S, S, DUM(1), DUM(1),
+     $                      DUM(1),
      $                      -1, INFO )
                LWORK_ZGEBRD = INT( DUM(1) )
 *              Compute space needed for ZUNMBR
-               CALL ZUNMBR( 'Q', 'L', 'C', MM, NRHS, N, A, LDA, DUM(1),
+               CALL ZUNMBR( 'Q', 'L', 'C', MM, NRHS, N, A, LDA,
+     $                      DUM(1),
      $                B, LDB, DUM(1), -1, INFO )
                LWORK_ZUNMBR = INT( DUM(1) )
 *              Compute space needed for ZUNGBR
@@ -422,13 +427,15 @@
 *
 *        Scale matrix norm up to SMLNUM
 *
-         CALL ZLASCL( 'G', 0, 0, BNRM, SMLNUM, M, NRHS, B, LDB, INFO )
+         CALL ZLASCL( 'G', 0, 0, BNRM, SMLNUM, M, NRHS, B, LDB,
+     $                INFO )
          IBSCL = 1
       ELSE IF( BNRM.GT.BIGNUM ) THEN
 *
 *        Scale matrix norm down to BIGNUM
 *
-         CALL ZLASCL( 'G', 0, 0, BNRM, BIGNUM, M, NRHS, B, LDB, INFO )
+         CALL ZLASCL( 'G', 0, 0, BNRM, BIGNUM, M, NRHS, B, LDB,
+     $                INFO )
          IBSCL = 2
       END IF
 *
@@ -458,7 +465,8 @@
 *           (CWorkspace: need N+NRHS, prefer N+NRHS*NB)
 *           (RWorkspace: none)
 *
-            CALL ZUNMQR( 'L', 'C', M, NRHS, N, A, LDA, WORK( ITAU ), B,
+            CALL ZUNMQR( 'L', 'C', M, NRHS, N, A, LDA, WORK( ITAU ),
+     $                   B,
      $                   LDB, WORK( IWORK ), LWORK-IWORK+1, INFO )
 *
 *           Zero out below R
@@ -485,7 +493,8 @@
 *        (CWorkspace: need 2*N+NRHS, prefer 2*N+NRHS*NB)
 *        (RWorkspace: none)
 *
-         CALL ZUNMBR( 'Q', 'L', 'C', MM, NRHS, N, A, LDA, WORK( ITAUQ ),
+         CALL ZUNMBR( 'Q', 'L', 'C', MM, NRHS, N, A, LDA,
+     $                WORK( ITAUQ ),
      $                B, LDB, WORK( IWORK ), LWORK-IWORK+1, INFO )
 *
 *        Generate right bidiagonalizing vectors of R in A
@@ -502,7 +511,8 @@
 *        (CWorkspace: none)
 *        (RWorkspace: need BDSPAC)
 *
-         CALL ZBDSQR( 'U', N, N, 0, NRHS, S, RWORK( IE ), A, LDA, DUM,
+         CALL ZBDSQR( 'U', N, N, 0, NRHS, S, RWORK( IE ), A, LDA,
+     $                DUM,
      $                1, B, LDB, RWORK( IRWORK ), INFO )
          IF( INFO.NE.0 )
      $      GO TO 70
@@ -518,7 +528,8 @@
                CALL ZDRSCL( NRHS, S( I ), B( I, 1 ), LDB )
                RANK = RANK + 1
             ELSE
-               CALL ZLASET( 'F', 1, NRHS, CZERO, CZERO, B( I, 1 ), LDB )
+               CALL ZLASET( 'F', 1, NRHS, CZERO, CZERO, B( I, 1 ),
+     $                      LDB )
             END IF
    10    CONTINUE
 *
@@ -534,12 +545,14 @@
             CHUNK = LWORK / N
             DO 20 I = 1, NRHS, CHUNK
                BL = MIN( NRHS-I+1, CHUNK )
-               CALL ZGEMM( 'C', 'N', N, BL, N, CONE, A, LDA, B( 1, I ),
+               CALL ZGEMM( 'C', 'N', N, BL, N, CONE, A, LDA, B( 1,
+     $                     I ),
      $                     LDB, CZERO, WORK, N )
                CALL ZLACPY( 'G', N, BL, WORK, N, B( 1, I ), LDB )
    20       CONTINUE
          ELSE IF( NRHS.EQ.1 ) THEN
-            CALL ZGEMV( 'C', N, N, CONE, A, LDA, B, 1, CZERO, WORK, 1 )
+            CALL ZGEMV( 'C', N, N, CONE, A, LDA, B, 1, CZERO, WORK,
+     $                  1 )
             CALL ZCOPY( N, WORK, 1, B, 1 )
          END IF
 *
@@ -595,7 +608,8 @@
 *        (CWorkspace: need M*M+4*M-1, prefer M*M+3*M+(M-1)*NB)
 *        (RWorkspace: none)
 *
-         CALL ZUNGBR( 'P', M, M, M, WORK( IL ), LDWORK, WORK( ITAUP ),
+         CALL ZUNGBR( 'P', M, M, M, WORK( IL ), LDWORK,
+     $                WORK( ITAUP ),
      $                WORK( IWORK ), LWORK-IWORK+1, INFO )
          IRWORK = IE + M
 *
@@ -621,7 +635,8 @@
                CALL ZDRSCL( NRHS, S( I ), B( I, 1 ), LDB )
                RANK = RANK + 1
             ELSE
-               CALL ZLASET( 'F', 1, NRHS, CZERO, CZERO, B( I, 1 ), LDB )
+               CALL ZLASET( 'F', 1, NRHS, CZERO, CZERO, B( I, 1 ),
+     $                      LDB )
             END IF
    30    CONTINUE
          IWORK = IL + M*LDWORK
@@ -631,27 +646,30 @@
 *        (RWorkspace: none)
 *
          IF( LWORK.GE.LDB*NRHS+IWORK-1 .AND. NRHS.GT.1 ) THEN
-            CALL ZGEMM( 'C', 'N', M, NRHS, M, CONE, WORK( IL ), LDWORK,
+            CALL ZGEMM( 'C', 'N', M, NRHS, M, CONE, WORK( IL ),
+     $                  LDWORK,
      $                  B, LDB, CZERO, WORK( IWORK ), LDB )
             CALL ZLACPY( 'G', M, NRHS, WORK( IWORK ), LDB, B, LDB )
          ELSE IF( NRHS.GT.1 ) THEN
             CHUNK = ( LWORK-IWORK+1 ) / M
             DO 40 I = 1, NRHS, CHUNK
                BL = MIN( NRHS-I+1, CHUNK )
-               CALL ZGEMM( 'C', 'N', M, BL, M, CONE, WORK( IL ), LDWORK,
+               CALL ZGEMM( 'C', 'N', M, BL, M, CONE, WORK( IL ),
+     $                     LDWORK,
      $                     B( 1, I ), LDB, CZERO, WORK( IWORK ), M )
                CALL ZLACPY( 'G', M, BL, WORK( IWORK ), M, B( 1, I ),
      $                      LDB )
    40       CONTINUE
          ELSE IF( NRHS.EQ.1 ) THEN
-            CALL ZGEMV( 'C', M, M, CONE, WORK( IL ), LDWORK, B( 1, 1 ),
-     $                  1, CZERO, WORK( IWORK ), 1 )
+            CALL ZGEMV( 'C', M, M, CONE, WORK( IL ), LDWORK, B( 1,
+     $                  1 ), 1, CZERO, WORK( IWORK ), 1 )
             CALL ZCOPY( M, WORK( IWORK ), 1, B( 1, 1 ), 1 )
          END IF
 *
 *        Zero out below first M rows of B
 *
-         CALL ZLASET( 'F', N-M, NRHS, CZERO, CZERO, B( M+1, 1 ), LDB )
+         CALL ZLASET( 'F', N-M, NRHS, CZERO, CZERO, B( M+1, 1 ),
+     $                LDB )
          IWORK = ITAU + M
 *
 *        Multiply transpose(Q) by B
@@ -682,7 +700,8 @@
 *        (CWorkspace: need 2*M+NRHS, prefer 2*M+NRHS*NB)
 *        (RWorkspace: none)
 *
-         CALL ZUNMBR( 'Q', 'L', 'C', M, NRHS, N, A, LDA, WORK( ITAUQ ),
+         CALL ZUNMBR( 'Q', 'L', 'C', M, NRHS, N, A, LDA,
+     $                WORK( ITAUQ ),
      $                B, LDB, WORK( IWORK ), LWORK-IWORK+1, INFO )
 *
 *        Generate right bidiagonalizing vectors in A
@@ -699,7 +718,8 @@
 *        (CWorkspace: none)
 *        (RWorkspace: need BDSPAC)
 *
-         CALL ZBDSQR( 'L', M, N, 0, NRHS, S, RWORK( IE ), A, LDA, DUM,
+         CALL ZBDSQR( 'L', M, N, 0, NRHS, S, RWORK( IE ), A, LDA,
+     $                DUM,
      $                1, B, LDB, RWORK( IRWORK ), INFO )
          IF( INFO.NE.0 )
      $      GO TO 70
@@ -715,7 +735,8 @@
                CALL ZDRSCL( NRHS, S( I ), B( I, 1 ), LDB )
                RANK = RANK + 1
             ELSE
-               CALL ZLASET( 'F', 1, NRHS, CZERO, CZERO, B( I, 1 ), LDB )
+               CALL ZLASET( 'F', 1, NRHS, CZERO, CZERO, B( I, 1 ),
+     $                      LDB )
             END IF
    50    CONTINUE
 *
@@ -731,12 +752,14 @@
             CHUNK = LWORK / N
             DO 60 I = 1, NRHS, CHUNK
                BL = MIN( NRHS-I+1, CHUNK )
-               CALL ZGEMM( 'C', 'N', N, BL, M, CONE, A, LDA, B( 1, I ),
+               CALL ZGEMM( 'C', 'N', N, BL, M, CONE, A, LDA, B( 1,
+     $                     I ),
      $                     LDB, CZERO, WORK, N )
                CALL ZLACPY( 'F', N, BL, WORK, N, B( 1, I ), LDB )
    60       CONTINUE
          ELSE IF( NRHS.EQ.1 ) THEN
-            CALL ZGEMV( 'C', M, N, CONE, A, LDA, B, 1, CZERO, WORK, 1 )
+            CALL ZGEMV( 'C', M, N, CONE, A, LDA, B, 1, CZERO, WORK,
+     $                  1 )
             CALL ZCOPY( N, WORK, 1, B, 1 )
          END IF
       END IF
@@ -744,18 +767,22 @@
 *     Undo scaling
 *
       IF( IASCL.EQ.1 ) THEN
-         CALL ZLASCL( 'G', 0, 0, ANRM, SMLNUM, N, NRHS, B, LDB, INFO )
+         CALL ZLASCL( 'G', 0, 0, ANRM, SMLNUM, N, NRHS, B, LDB,
+     $                INFO )
          CALL DLASCL( 'G', 0, 0, SMLNUM, ANRM, MINMN, 1, S, MINMN,
      $                INFO )
       ELSE IF( IASCL.EQ.2 ) THEN
-         CALL ZLASCL( 'G', 0, 0, ANRM, BIGNUM, N, NRHS, B, LDB, INFO )
+         CALL ZLASCL( 'G', 0, 0, ANRM, BIGNUM, N, NRHS, B, LDB,
+     $                INFO )
          CALL DLASCL( 'G', 0, 0, BIGNUM, ANRM, MINMN, 1, S, MINMN,
      $                INFO )
       END IF
       IF( IBSCL.EQ.1 ) THEN
-         CALL ZLASCL( 'G', 0, 0, SMLNUM, BNRM, N, NRHS, B, LDB, INFO )
+         CALL ZLASCL( 'G', 0, 0, SMLNUM, BNRM, N, NRHS, B, LDB,
+     $                INFO )
       ELSE IF( IBSCL.EQ.2 ) THEN
-         CALL ZLASCL( 'G', 0, 0, BIGNUM, BNRM, N, NRHS, B, LDB, INFO )
+         CALL ZLASCL( 'G', 0, 0, BIGNUM, BNRM, N, NRHS, B, LDB,
+     $                INFO )
       END IF
    70 CONTINUE
       WORK( 1 ) = MAXWRK
